Command Line Interface
======================
bioontologies automatically installs the command :code:`bioontologies`. See
:code:`bioontologies --help` for usage details.

.. click:: bioontologies.cli:main
   :prog: bioontologies
   :show-nested:
